'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var reactKit = require('@flive/react-kit');
var React = _interopDefault(require('react'));
var PropTypes = _interopDefault(require('prop-types'));

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};

  var target = _objectWithoutPropertiesLoose(source, excluded);

  var key, i;

  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }

  return target;
}

var propTypes = {
  input: PropTypes.shape({
    id: PropTypes.string,
    name: PropTypes.string,
    // eslint-disable-next-line react/forbid-prop-types
    value: PropTypes.any,
    onBlur: PropTypes.func,
    onChange: PropTypes.func,
    onDragStart: PropTypes.func,
    onDrop: PropTypes.func,
    onFocus: PropTypes.func
  }),
  inputRef: PropTypes.func,
  meta: PropTypes.shape({
    // eslint-disable-next-line react/forbid-prop-types
    error: PropTypes.any,
    touched: PropTypes.bool
  })
};
var defaultProps = {
  input: {
    id: undefined,
    name: undefined,
    value: undefined,
    onBlur: undefined,
    onChange: undefined,
    onDragStart: undefined,
    onDrop: undefined,
    onFocus: undefined
  },
  inputRef: undefined,
  meta: {
    error: undefined,
    touched: undefined
  }
};

var withReduxFormInput = function withReduxFormInput(Input) {
  var InputWithReduxForm = function InputWithReduxForm(props) {
    var input = props.input,
        meta = props.meta,
        inputRef = props.inputRef,
        rest = _objectWithoutProperties(props, ["input", "meta", "inputRef"]);

    var value = input.value,
        name = input.name,
        id = input.id,
        inputRest = _objectWithoutProperties(input, ["value", "name", "id"]);

    return /*#__PURE__*/React.createElement(Input, _extends({}, inputRest, typeof value === 'boolean' ? {
      checked: value,
      value: name,
      name: name
    } : {
      value: value,
      name: name
    }, id ? {
      id: id
    } : {
      id: name
    }, meta.touched && meta.error && {
      invalid: true
    }, {
      ref: inputRef
    }, rest));
  };

  var componentName = Input.displayName || Input.name;
  InputWithReduxForm.propTypes = propTypes;
  InputWithReduxForm.defaultProps = defaultProps;
  InputWithReduxForm.displayName = "withReduxFormInput(".concat(componentName, ")");
  return InputWithReduxForm;
};

var propTypes$1 = {
  input: PropTypes.shape({
    checked: PropTypes.bool,
    id: PropTypes.string,
    name: PropTypes.string,
    // eslint-disable-next-line react/forbid-prop-types
    value: PropTypes.any,
    onBlur: PropTypes.func,
    onChange: PropTypes.func,
    onDragStart: PropTypes.func,
    onDrop: PropTypes.func,
    onFocus: PropTypes.func
  }),
  inputRef: PropTypes.func,
  meta: PropTypes.shape({
    // eslint-disable-next-line react/forbid-prop-types
    error: PropTypes.any,
    touched: PropTypes.bool
  })
};
var defaultProps$1 = {
  input: {
    id: undefined,
    name: undefined,
    value: undefined,
    onBlur: undefined,
    onChange: undefined,
    onDragStart: undefined,
    onDrop: undefined,
    onFocus: undefined
  },
  inputRef: undefined,
  meta: {
    error: undefined,
    touched: undefined
  }
};

var withReduxFormField = function withReduxFormField(Field) {
  var FieldWithReduxForm = function FieldWithReduxForm(props) {
    var input = props.input,
        meta = props.meta,
        inputRef = props.inputRef,
        rest = _objectWithoutProperties(props, ["input", "meta", "inputRef"]);

    var value = input.value,
        name = input.name,
        id = input.id,
        inputRest = _objectWithoutProperties(input, ["value", "name", "id"]);

    return /*#__PURE__*/React.createElement(Field, _extends({}, inputRest, typeof value === 'boolean' ? {
      checked: value,
      value: name,
      name: name
    } : {
      value: value,
      name: name
    }, id ? {
      id: id
    } : {
      id: name
    }, meta.touched && meta.error && {
      error: meta.error,
      invalid: true
    }, {
      ref: inputRef
    }, rest));
  };

  var componentName = Field.displayName || Field.name;
  FieldWithReduxForm.propTypes = propTypes$1;
  FieldWithReduxForm.defaultProps = defaultProps$1;
  FieldWithReduxForm.displayName = "withReduxFormField(".concat(componentName, ")");
  return FieldWithReduxForm;
};

// eslint-disable-next-line import/no-unresolved

var Input = withReduxFormInput(reactKit.Form.Input);
var TextInput = withReduxFormInput(reactKit.Form.TextInput);
var NumberInput = withReduxFormInput(reactKit.Form.NumberInput);
var PasswordInput = withReduxFormInput(reactKit.Form.PasswordInput);
var TextareaInput = withReduxFormInput(reactKit.Form.TextareaInput);
var NativeSelectInput = withReduxFormInput(reactKit.Form.NativeSelectInput);
var CheckboxInput = withReduxFormInput(reactKit.Form.CheckboxInput);
var RadioInput = withReduxFormInput(reactKit.Form.RadioInput);
var ToggleInput = withReduxFormInput(reactKit.Form.ToggleInput);
var SelectInput = withReduxFormInput(reactKit.Form.SelectInput); // Fields

var TextField = withReduxFormField(reactKit.Form.TextField);
var PasswordField = withReduxFormField(reactKit.Form.PasswordField);
var NumberField = withReduxFormField(reactKit.Form.NumberField);
var TextareaField = withReduxFormField(reactKit.Form.TextareaField);
var NativeSelectField = withReduxFormField(reactKit.Form.NativeSelectField);
var CheckboxField = withReduxFormField(reactKit.Form.CheckboxField);
var CheckboxesField = withReduxFormField(reactKit.Form.CheckboxesField);
var RadiosField = withReduxFormField(reactKit.Form.RadiosField);
var ToggleField = withReduxFormField(reactKit.Form.ToggleField);
var SelectField = withReduxFormField(reactKit.Form.SelectField);

exports.CheckboxField = CheckboxField;
exports.CheckboxInput = CheckboxInput;
exports.CheckboxesField = CheckboxesField;
exports.Input = Input;
exports.NativeSelectField = NativeSelectField;
exports.NativeSelectInput = NativeSelectInput;
exports.NumberField = NumberField;
exports.NumberInput = NumberInput;
exports.PasswordField = PasswordField;
exports.PasswordInput = PasswordInput;
exports.RadioInput = RadioInput;
exports.RadiosField = RadiosField;
exports.SelectField = SelectField;
exports.SelectInput = SelectInput;
exports.TextField = TextField;
exports.TextInput = TextInput;
exports.TextareaField = TextareaField;
exports.TextareaInput = TextareaInput;
exports.ToggleField = ToggleField;
exports.ToggleInput = ToggleInput;
exports.withReduxFormField = withReduxFormField;
exports.withReduxFormInput = withReduxFormInput;
//# sourceMappingURL=index.cjs.js.map
